summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--action.cpp28
-rw-r--r--action_efi.cpp6
-rw-r--r--action_vbox.cpp10
-rw-r--r--apppbx.cpp56
-rw-r--r--crypt.cpp16
-rw-r--r--dss1.cpp48
-rw-r--r--dss1.h4
-rw-r--r--joinpbx.cpp12
-rw-r--r--joinremote.cpp4
-rw-r--r--mISDN.cpp10
-rw-r--r--main.c2
-rw-r--r--message.c26
-rw-r--r--message.h14
-rw-r--r--port.cpp10
-rw-r--r--vbox.cpp4
15 files changed, 125 insertions, 125 deletions
diff --git a/action.cpp b/action.cpp
index 83e4965..67c8396 100644
--- a/action.cpp
+++ b/action.cpp
@@ -121,7 +121,7 @@ void EndpointAppPBX::action_init_remote(void)
{
struct route_param *rparam;
struct port_list *portlist = ea_endpoint->ep_portlist;
- struct message *message;
+ struct lcr_msg *message;
struct capa_info capainfo;
struct caller_info callerinfo;
struct redir_info redirinfo;
@@ -169,7 +169,7 @@ void EndpointAppPBX::action_dialing_internal(void)
struct redir_info redirinfo;
struct dialing_info dialinginfo;
struct port_list *portlist = ea_endpoint->ep_portlist;
- struct message *message;
+ struct lcr_msg *message;
struct extension ext;
struct route_param *rparam;
@@ -277,7 +277,7 @@ void EndpointAppPBX::action_dialing_external(void)
struct dialing_info dialinginfo;
char *p;
struct port_list *portlist = ea_endpoint->ep_portlist;
- struct message *message;
+ struct lcr_msg *message;
struct route_param *rparam;
/* special processing of delete characters '*' and '#' */
@@ -438,7 +438,7 @@ void EndpointAppPBX::action_dialing_external(void)
void EndpointAppPBX::action_dialing_remote(void)
{
- struct message *message;
+ struct lcr_msg *message;
struct dialing_info dialinginfo;
// struct route_param *rparam;
@@ -465,7 +465,7 @@ void EndpointAppPBX::action_dialing_vbox_record(void)
{
struct dialing_info dialinginfo;
struct port_list *portlist = ea_endpoint->ep_portlist;
- struct message *message;
+ struct lcr_msg *message;
struct extension ext;
struct route_param *rparam;
@@ -546,7 +546,7 @@ void EndpointAppPBX::action_init_partyline(void)
class Join *join;
class JoinPBX *joinpbx;
struct port_list *portlist = ea_endpoint->ep_portlist;
- struct message *message;
+ struct lcr_msg *message;
struct route_param *rparam;
int partyline, jingle = 0;
struct join_relation *relation;
@@ -647,7 +647,7 @@ void EndpointAppPBX::action_hangup_call(void)
void EndpointAppPBX::action_dialing_login(void)
{
struct port_list *portlist = ea_endpoint->ep_portlist;
- struct message *message;
+ struct lcr_msg *message;
char *extension;
struct route_param *rparam;
@@ -991,7 +991,7 @@ void EndpointAppPBX::action_init_redial_reply(void)
*/
void EndpointAppPBX::_action_redial_reply(int in)
{
- struct message *message;
+ struct lcr_msg *message;
char *last;
struct route_param *rparam;
@@ -1090,7 +1090,7 @@ void EndpointAppPBX::action_dialing_reply(void)
void EndpointAppPBX::action_dialing_powerdial(void)
{
struct port_list *portlist = ea_endpoint->ep_portlist;
- struct message *message;
+ struct lcr_msg *message;
struct route_param *rparam;
/* power dialing only possible if we have a last dialed number */
@@ -1321,7 +1321,7 @@ void EndpointAppPBX::action_dialing_test(void)
unsigned int cause;
char causestr[16];
struct port_list *portlist = ea_endpoint->ep_portlist;
- struct message *message;
+ struct lcr_msg *message;
class Port *port;
char testcode[32] = "";
struct route_param *rparam;
@@ -1533,7 +1533,7 @@ void EndpointAppPBX::action_init_play(void)
void EndpointAppPBX::action_dialing_calculator(void)
{
struct port_list *portlist = ea_endpoint->ep_portlist;
- struct message *message;
+ struct lcr_msg *message;
double value1, value2, v, sign1;
int komma1, komma2, k, state, mode, first;
char *p;
@@ -1877,7 +1877,7 @@ void EndpointAppPBX::action_dialing_disconnect(void)
{
struct route_param *rparam;
struct port_list *portlist = ea_endpoint->ep_portlist;
- struct message *message;
+ struct lcr_msg *message;
int cause = CAUSE_NORMAL; /* normal call clearing */
int location = LOCATION_PRIVATE_LOCAL;
char cause_string[256] = "", display[84] = "";
@@ -1947,7 +1947,7 @@ void EndpointAppPBX::action_dialing_help(void)
struct numbering *numbering = numbering_int;
char dialing[sizeof(e_dialinginfo.id)];
int i;
- struct message *message;
+ struct lcr_msg *message;
struct route_param *rparam;
/* in case we have no menu (this should never happen) */
@@ -2222,7 +2222,7 @@ void EndpointAppPBX::action_dialing_password_wr(void)
void EndpointAppPBX::process_dialing(void)
{
struct port_list *portlist = ea_endpoint->ep_portlist;
- struct message *message;
+ struct lcr_msg *message;
struct route_param *rparam;
//#warning Due to HANG-BUG somewhere here, I added some HANG-BUG-DEBUGGING output that cannot be disabled. after bug has been found, this will be removed.
diff --git a/action_efi.cpp b/action_efi.cpp
index 45a8119..76c902f 100644
--- a/action_efi.cpp
+++ b/action_efi.cpp
@@ -33,7 +33,7 @@ void EndpointAppPBX::action_init_efi(void)
{
// int language = e_ext.vbox_language;
// struct route_param *rparam;
- struct message *message;
+ struct lcr_msg *message;
struct port_list *portlist = ea_endpoint->ep_portlist;
/* if no caller id */
@@ -70,7 +70,7 @@ void EndpointAppPBX::efi_message_eof(void)
{
// char buffer[32];
char digit[] = "number_00";
-// struct message *message;
+// struct lcr_msg *message;
// struct port_list *portlist = ea_endpoint->ep_portlist;
PDEBUG(DEBUG_EPOINT, "EPOINT(%d) terminal %s end of file during state: %d\n", ea_endpoint->ep_serial, e_ext.number, e_vbox_state);
@@ -148,7 +148,7 @@ void EndpointAppPBX::efi_message_eof(void)
*/
void EndpointAppPBX::set_tone_efi(char *tone)
{
- struct message *message;
+ struct lcr_msg *message;
if (tone == NULL)
tone = "";
diff --git a/action_vbox.cpp b/action_vbox.cpp
index 49a91b5..e069299 100644
--- a/action_vbox.cpp
+++ b/action_vbox.cpp
@@ -80,7 +80,7 @@ void EndpointAppPBX::action_init_vbox_play(void)
{
int language = e_ext.vbox_language;
struct route_param *rparam;
- struct message *message;
+ struct lcr_msg *message;
struct port_list *portlist = ea_endpoint->ep_portlist;
/* get extension */
@@ -668,7 +668,7 @@ void EndpointAppPBX::vbox_handler(void)
if (e_vbox_display_refresh && e_ext.vbox_display!=VBOX_DISPLAY_OFF)
{
char counter[32];
- struct message *message;
+ struct lcr_msg *message;
SPRINT(counter, "%02d:%02d", e_vbox_counter/60, e_vbox_counter%60);
if (e_vbox_counter_max)
@@ -899,7 +899,7 @@ void EndpointAppPBX::vbox_message_eof(void)
*/
void EndpointAppPBX::set_tone_vbox(char *tone)
{
- struct message *message;
+ struct lcr_msg *message;
if (tone == NULL)
tone = "";
@@ -927,7 +927,7 @@ void EndpointAppPBX::set_tone_vbox(char *tone)
void EndpointAppPBX::set_play_vbox(char *file, int offset)
{
char filename[256];
- struct message *message;
+ struct lcr_msg *message;
SPRINT(filename, "%s/%s/%s/vbox/%s", INSTALL_DATA, options.extensions_dir, e_vbox, file);
@@ -958,7 +958,7 @@ void EndpointAppPBX::set_play_vbox(char *file, int offset)
*/
void EndpointAppPBX::set_play_speed(int speed)
{
- struct message *message;
+ struct lcr_msg *message;
if (!ea_endpoint->ep_portlist)
{
diff --git a/apppbx.cpp b/apppbx.cpp
index 3788c85..a0a14d0 100644
--- a/apppbx.cpp
+++ b/apppbx.cpp
@@ -179,7 +179,7 @@ void EndpointAppPBX::new_state(int state)
void EndpointAppPBX::release(int release, int joinlocation, int joincause, int portlocation, int portcause)
{
struct port_list *portlist;
- struct message *message;
+ struct lcr_msg *message;
char cause[16];
/* message to test call */
@@ -428,7 +428,7 @@ char *EndpointAppPBX::apply_callerid_display(char *id, int itype, int ntype, int
void EndpointAppPBX::notify_active(void)
{
struct port_list *portlist = ea_endpoint->ep_portlist;
- struct message *message;
+ struct lcr_msg *message;
int notify = 0;
switch(e_tx_state)
@@ -536,7 +536,7 @@ void EndpointAppPBX::keypad_function(char digit)
/* set tone pattern for port */
void EndpointAppPBX::set_tone(struct port_list *portlist, char *tone)
{
- struct message *message;
+ struct lcr_msg *message;
if (!tone)
tone = "";
@@ -830,7 +830,7 @@ void EndpointAppPBX::out_setup(void)
class Port *port;
// class pdss1 *pdss1;
struct port_list *portlist;
- struct message *message;
+ struct lcr_msg *message;
int anycall = 0;
int cause = CAUSE_RESSOURCEUNAVAIL;
char *p;
@@ -1325,7 +1325,7 @@ int EndpointAppPBX::handler(void)
if (e_cfnr_release)
{
struct port_list *portlist;
- struct message *message;
+ struct lcr_msg *message;
if (now >= e_cfnr_release)
{
@@ -1466,7 +1466,7 @@ void EndpointAppPBX::hookflash(void)
/* port MESSAGE_SETUP */
void EndpointAppPBX::port_setup(struct port_list *portlist, int message_type, union parameter *param)
{
- struct message *message;
+ struct lcr_msg *message;
char buffer[256];
int writeext; /* flags need to write extension after modification */
class Port *port;
@@ -1849,7 +1849,7 @@ void EndpointAppPBX::port_crypt(struct port_list *portlist, int message_type, un
/* port MESSAGE_OVERLAP */
void EndpointAppPBX::port_overlap(struct port_list *portlist, int message_type, union parameter *param)
{
- struct message *message;
+ struct lcr_msg *message;
logmessage(message_type, param, portlist->port_id, DIRECTION_IN);
@@ -1902,7 +1902,7 @@ void EndpointAppPBX::port_overlap(struct port_list *portlist, int message_type,
/* port MESSAGE_PROCEEDING */
void EndpointAppPBX::port_proceeding(struct port_list *portlist, int message_type, union parameter *param)
{
- struct message *message;
+ struct lcr_msg *message;
logmessage(message_type, param, portlist->port_id, DIRECTION_IN);
@@ -1944,7 +1944,7 @@ void EndpointAppPBX::port_proceeding(struct port_list *portlist, int message_typ
/* port MESSAGE_ALERTING */
void EndpointAppPBX::port_alerting(struct port_list *portlist, int message_type, union parameter *param)
{
- struct message *message;
+ struct lcr_msg *message;
logmessage(message_type, param, portlist->port_id, DIRECTION_IN);
@@ -1986,7 +1986,7 @@ void EndpointAppPBX::port_alerting(struct port_list *portlist, int message_type,
/* port MESSAGE_CONNECT */
void EndpointAppPBX::port_connect(struct port_list *portlist, int message_type, union parameter *param)
{
- struct message *message;
+ struct lcr_msg *message;
char buffer[256];
unsigned long port_id = portlist->port_id;
struct port_list *tportlist;
@@ -2196,7 +2196,7 @@ void EndpointAppPBX::port_connect(struct port_list *portlist, int message_type,
/* port MESSAGE_DISCONNECT MESSAGE_RELEASE */
void EndpointAppPBX::port_disconnect_release(struct port_list *portlist, int message_type, union parameter *param)
{
- struct message *message;
+ struct lcr_msg *message;
char buffer[256];
unsigned long port_id = portlist->port_id;
int cause,
@@ -2410,7 +2410,7 @@ void EndpointAppPBX::port_notify(struct port_list *portlist, int message_type, u
{
logmessage(message_type, param, portlist->port_id, DIRECTION_IN);
- struct message *message;
+ struct lcr_msg *message;
char *logtext = "";
char buffer[64];
@@ -2557,7 +2557,7 @@ void EndpointAppPBX::port_facility(struct port_list *portlist, int message_type,
{
logmessage(message_type, param, portlist->port_id, DIRECTION_IN);
- struct message *message;
+ struct lcr_msg *message;
message = message_create(ea_endpoint->ep_serial, ea_endpoint->ep_join_id, EPOINT_TO_JOIN, MESSAGE_FACILITY);
memcpy(&message->param.facilityinfo, &param->facilityinfo, sizeof(struct facility_info));
@@ -2596,7 +2596,7 @@ void EndpointAppPBX::port_resume(struct port_list *portlist, int message_type, u
void EndpointAppPBX::ea_message_port(unsigned long port_id, int message_type, union parameter *param)
{
struct port_list *portlist;
- struct message *message;
+ struct lcr_msg *message;
portlist = ea_endpoint->ep_portlist;
while(portlist)
@@ -2826,7 +2826,7 @@ void EndpointAppPBX::join_crypt(struct port_list *portlist, int message_type, un
/* join MESSAGE_INFORMATION */
void EndpointAppPBX::join_information(struct port_list *portlist, int message_type, union parameter *param)
{
- struct message *message;
+ struct lcr_msg *message;
e_overlap = 1;
@@ -2843,7 +2843,7 @@ void EndpointAppPBX::join_information(struct port_list *portlist, int message_ty
/* join MESSAGE_FACILITY */
void EndpointAppPBX::join_facility(struct port_list *portlist, int message_type, union parameter *param)
{
- struct message *message;
+ struct lcr_msg *message;
if (!e_ext.facility && e_ext.number[0])
{
@@ -2863,7 +2863,7 @@ void EndpointAppPBX::join_facility(struct port_list *portlist, int message_type,
/* join MESSAGE_MORE */
void EndpointAppPBX::join_overlap(struct port_list *portlist, int message_type, union parameter *param)
{
- struct message *message;
+ struct lcr_msg *message;
new_state(EPOINT_STATE_IN_OVERLAP);
@@ -2892,7 +2892,7 @@ void EndpointAppPBX::join_overlap(struct port_list *portlist, int message_type,
/* join MESSAGE_PROCEEDING */
void EndpointAppPBX::join_proceeding(struct port_list *portlist, int message_type, union parameter *param)
{
- struct message *message;
+ struct lcr_msg *message;
new_state(EPOINT_STATE_IN_PROCEEDING);
@@ -2920,7 +2920,7 @@ void EndpointAppPBX::join_proceeding(struct port_list *portlist, int message_typ
/* join MESSAGE_ALERTING */
void EndpointAppPBX::join_alerting(struct port_list *portlist, int message_type, union parameter *param)
{
- struct message *message;
+ struct lcr_msg *message;
new_state(EPOINT_STATE_IN_ALERTING);
@@ -2955,7 +2955,7 @@ void EndpointAppPBX::join_alerting(struct port_list *portlist, int message_type,
/* join MESSAGE_CONNECT */
void EndpointAppPBX::join_connect(struct port_list *portlist, int message_type, union parameter *param)
{
- struct message *message;
+ struct lcr_msg *message;
new_state(EPOINT_STATE_CONNECT);
// UCPY(e_join_tone, "");
@@ -3008,7 +3008,7 @@ void EndpointAppPBX::join_connect(struct port_list *portlist, int message_type,
void EndpointAppPBX::join_disconnect_release(int message_type, union parameter *param)
{
char cause[16];
- struct message *message;
+ struct lcr_msg *message;
struct port_list *portlist = NULL;
@@ -3122,7 +3122,7 @@ void EndpointAppPBX::join_disconnect_release(int message_type, union parameter *
/* join MESSAGE_SETUP */
void EndpointAppPBX::join_setup(struct port_list *portlist, int message_type, union parameter *param)
{
- struct message *message;
+ struct lcr_msg *message;
// struct interface *interface;
/* if we already in setup state, we just update the dialing with new digits */
@@ -3238,7 +3238,7 @@ void EndpointAppPBX::join_setup(struct port_list *portlist, int message_type, un
/* join MESSAGE_mISDNSIGNAL */
void EndpointAppPBX::join_mISDNsignal(struct port_list *portlist, int message_type, union parameter *param)
{
- struct message *message;
+ struct lcr_msg *message;
while(portlist)
{
@@ -3252,7 +3252,7 @@ void EndpointAppPBX::join_mISDNsignal(struct port_list *portlist, int message_ty
/* join MESSAGE_NOTIFY */
void EndpointAppPBX::join_notify(struct port_list *portlist, int message_type, union parameter *param)
{
- struct message *message;
+ struct lcr_msg *message;
int new_state;
if (param->notifyinfo.notify)
@@ -3316,7 +3316,7 @@ void EndpointAppPBX::join_notify(struct port_list *portlist, int message_type, u
void EndpointAppPBX::ea_message_join(unsigned long join_id, int message_type, union parameter *param)
{
struct port_list *portlist;
- struct message *message;
+ struct lcr_msg *message;
if (!join_id)
{
@@ -3555,7 +3555,7 @@ int match_list(char *list, char *item)
void EndpointAppPBX::pick_join(char *extensions)
{
- struct message *message;
+ struct lcr_msg *message;
struct port_list *portlist;
class Port *port;
class EndpointAppPBX *eapp, *found;
@@ -3761,7 +3761,7 @@ reject:
*/
void EndpointAppPBX::join_join(void)
{
- struct message *message;
+ struct lcr_msg *message;
struct join_relation *our_relation, *other_relation;
struct join_relation **our_relation_pointer, **other_relation_pointer;
class Join *our_join, *other_join;
@@ -4371,7 +4371,7 @@ void EndpointAppPBX::logmessage(int message_type, union parameter *param, unsign
void EndpointAppPBX::message_disconnect_port(struct port_list *portlist, int cause, int location, char *display)
{
- struct message *message;
+ struct lcr_msg *message;
if (!portlist)
return;
diff --git a/crypt.cpp b/crypt.cpp
index 051dbb3..92f0c10 100644
--- a/crypt.cpp
+++ b/crypt.cpp
@@ -1451,7 +1451,7 @@ unsigned char *EndpointAppPBX::cryptman_getinf(unsigned char *buf, int element,
*/
void EndpointAppPBX::cryptman_msg2peer(unsigned char *buf)
{
- struct message *message;
+ struct lcr_msg *message;
unsigned char *p = buf;
int len = 0;
int l;
@@ -1493,7 +1493,7 @@ void EndpointAppPBX::cryptman_msg2peer(unsigned char *buf)
*/
void EndpointAppPBX::cryptman_msg2crengine(int msg, unsigned char *buf, int len)
{
- struct message *message;
+ struct lcr_msg *message;
if (len > (int)sizeof(message->param.crypt.data))
{
@@ -1522,7 +1522,7 @@ void EndpointAppPBX::cryptman_msg2crengine(int msg, unsigned char *buf, int len)
*/
void EndpointAppPBX::cryptman_msg2user(int msg, char *text)
{
- struct message *message;
+ struct lcr_msg *message;
/* send message */
message = message_create(ea_endpoint->ep_serial, ea_endpoint->ep_join_id, EPOINT_TO_JOIN, MESSAGE_CRYPT);
message->param.crypt.type = msg;
@@ -1617,7 +1617,7 @@ int cryptman_encode_bch(unsigned char *data, int len, unsigned char *buf, int bu
void PmISDN::cryptman_listen_bch(unsigned char *p, int l)
{
int i;
- struct message *message;
+ struct lcr_msg *message;
retry:
if (!l)
@@ -1791,7 +1791,7 @@ void PmISDN::cryptman_listen_bch(unsigned char *p, int l)
*/
void EndpointAppPBX::encrypt_shared(void)
{
- struct message *message;
+ struct lcr_msg *message;
char *errstr = "";
class Port *port;
int type, key_len;
@@ -1897,7 +1897,7 @@ void EndpointAppPBX::encrypt_shared(void)
*/
void EndpointAppPBX::encrypt_keyex(void)
{
- struct message *message;
+ struct lcr_msg *message;
char *errstr = "";
class Port *port;
@@ -1948,7 +1948,7 @@ void EndpointAppPBX::encrypt_keyex(void)
*/
void EndpointAppPBX::encrypt_off(void)
{
- struct message *message;
+ struct lcr_msg *message;
if (e_crypt!=CRYPT_ON && e_crypt!=CRYPT_OFF)
{
@@ -1985,7 +1985,7 @@ void EndpointAppPBX::encrypt_off(void)
*/
void EndpointAppPBX::encrypt_result(int msg, char *text)
{
- struct message *message;
+ struct lcr_msg *message;
switch(msg)
{
diff --git a/dss1.cpp b/dss1.cpp
index 795ba4a..3367bd2 100644
--- a/dss1.cpp
+++ b/dss1.cpp
@@ -523,7 +523,7 @@ void Pdss1::setup_ind(unsigned long prim, unsigned long dinfo, void *data)
unsigned char useruser[128];
int useruser_len = 0, useruser_protocol;
class Endpoint *epoint;
- struct message *message;
+ struct lcr_msg *message;
#ifdef SOCKET_MISDN
/* process given callref */
@@ -879,7 +879,7 @@ void Pdss1::information_ind(unsigned long prim, unsigned long dinfo, void *data)
#endif
int type, plan;
unsigned char keypad[32] = "";
- struct message *message;
+ struct lcr_msg *message;
l1l2l3_trace_header(p_m_mISDNport, this, L3_INFORMATION_IND, DIRECTION_IN);
#ifdef SOCKET_MISDN
@@ -929,7 +929,7 @@ void Pdss1::setup_acknowledge_ind(unsigned long prim, unsigned long dinfo, void
int exclusive, channel;
int coding, location, progress;
int ret;
- struct message *message;
+ struct lcr_msg *message;
l1l2l3_trace_header(p_m_mISDNport, this, L3_SETUP_ACKNOWLEDGE_IND, DIRECTION_IN);
#ifdef SOCKET_MISDN
@@ -977,7 +977,7 @@ void Pdss1::proceeding_ind(unsigned long prim, unsigned long dinfo, void *data)
int exclusive, channel;
int coding, location, progress;
int ret;
- struct message *message;
+ struct lcr_msg *message;
int notify = -1, type, plan, present;
char redir[32];
@@ -1076,7 +1076,7 @@ void Pdss1::alerting_ind(unsigned long prim, unsigned long dinfo, void *data)
int exclusive, channel;
int coding, location, progress;
int ret;
- struct message *message;
+ struct lcr_msg *message;
int notify = -1, type, plan, present;
char redir[32];
@@ -1177,7 +1177,7 @@ void Pdss1::connect_ind(unsigned long prim, unsigned long dinfo, void *data)
int exclusive, channel;
int type, plan, present, screen;
int ret;
- struct message *message;
+ struct lcr_msg *message;
int bchannel_before;
if (p_m_d_ntmode)
@@ -1310,7 +1310,7 @@ void Pdss1::disconnect_ind(unsigned long prim, unsigned long dinfo, void *data)
#endif
int location, cause;
int coding, proglocation, progress;
- struct message *message;
+ struct lcr_msg *message;
l1l2l3_trace_header(p_m_mISDNport, this, L3_DISCONNECT_IND, DIRECTION_IN);
#ifdef SOCKET_MISDN
@@ -1439,7 +1439,7 @@ void Pdss1::release_ind(unsigned long prim, unsigned long dinfo, void *data)
RELEASE_t *release = (RELEASE_t *)((unsigned long)data + headerlen);
#endif
int location, cause;
- struct message *message;
+ struct lcr_msg *message;
l1l2l3_trace_header(p_m_mISDNport, this, L3_RELEASE_IND, DIRECTION_IN);
#ifdef SOCKET_MISDN
@@ -1509,7 +1509,7 @@ void Pdss1::release_complete_ind(unsigned long prim, unsigned long dinfo, void *
RELEASE_COMPLETE_t *release_complete = (RELEASE_COMPLETE_t *)((unsigned long)data + headerlen);
#endif
int location, cause;
- struct message *message;
+ struct lcr_msg *message;
l1l2l3_trace_header(p_m_mISDNport, this, L3_RELEASE_COMPLETE_IND, DIRECTION_IN);
#ifdef SOCKET_MISDN
@@ -1547,7 +1547,7 @@ void Pdss1::t312_timeout_ind(unsigned int cmd, unsigned int pid, struct l3_msg *
void Pdss1::t312_timeout_ind(unsigned long prim, unsigned long dinfo, void *data)
{
#endif
- struct message *message;
+ struct lcr_msg *message;
// trace is done at message_isdn()
@@ -1583,7 +1583,7 @@ void Pdss1::notify_ind(unsigned long prim, unsigned long dinfo, void *data)
int headerlen = (p_m_d_ntmode)?mISDNUSER_HEAD_SIZE:mISDN_HEADER_LEN;
NOTIFY_t *notifying = (NOTIFY_t *)((unsigned long)data + headerlen);
#endif
- struct message *message;
+ struct lcr_msg *message;
int notify, type, plan, present;
unsigned char notifyid[sizeof(message->param.notifyinfo.id)];
@@ -1644,7 +1644,7 @@ void Pdss1::notify_ind(unsigned long prim, unsigned long dinfo, void *data)
/* CC_HOLD INDICATION */
- struct message *message;
+ struct lcr_msg *message;
#ifdef SOCKET_MISDN
void Pdss1::hold_ind(unsigned int cmd, unsigned int pid, struct l3_msg *l3m)
{
@@ -1740,7 +1740,7 @@ void Pdss1::retrieve_ind(unsigned long prim, unsigned long dinfo, void *data)
RETRIEVE_REJECT_t *retrieve_reject;
RETRIEVE_ACKNOWLEDGE_t *retrieve_acknowledge;
#endif
- struct message *message;
+ struct lcr_msg *message;
int channel, exclusive, cause;
int ret;
@@ -1838,7 +1838,7 @@ void Pdss1::suspend_ind(unsigned long prim, unsigned long dinfo, void *data)
SUSPEND_ACKNOWLEDGE_t *suspend_acknowledge;
SUSPEND_REJECT_t *suspend_reject;
#endif
- struct message *message;
+ struct lcr_msg *message;
class Endpoint *epoint;
unsigned char callid[8];
int len;
@@ -1955,7 +1955,7 @@ void Pdss1::resume_ind(unsigned long prim, unsigned long dinfo, void *data)
int len;
int channel, exclusive;
class Endpoint *epoint;
- struct message *message;
+ struct lcr_msg *message;
int ret;
#ifdef SOCKET_MISDN
@@ -2125,7 +2125,7 @@ void Pdss1::facility_ind(unsigned long prim, unsigned long dinfo, void *data)
#endif
unsigned char facil[256];
int facil_len;
- struct message *message;
+ struct lcr_msg *message;
l1l2l3_trace_header(p_m_mISDNport, this, L3_FACILITY_IND, DIRECTION_IN);
#ifdef SOCKET_MISDN
@@ -2298,7 +2298,7 @@ void Pdss1::message_isdn(unsigned int cmd, unsigned int pid, struct l3_msg *l3m)
*/
while(p_epointlist)
{
- struct message *message;
+ struct lcr_msg *message;
message = message_create(p_serial, p_epointlist->epoint_id, PORT_TO_EPOINT, MESSAGE_RELEASE);
message->param.disconnectinfo.cause = (p_m_d_collect_cause!=CAUSE_NOUSER)?p_m_d_collect_cause:CAUSE_UNSPECIFIED;
message->param.disconnectinfo.location = (p_m_d_collect_cause!=CAUSE_NOUSER)?p_m_d_collect_location:LOCATION_PRIVATE_LOCAL;
@@ -2484,7 +2484,7 @@ void Pdss1::message_isdn(unsigned long prim, unsigned long dinfo, void *data)
*/
while(p_epointlist)
{
- struct message *message;
+ struct lcr_msg *message;
message = message_create(p_serial, p_epointlist->epoint_id, PORT_TO_EPOINT, MESSAGE_RELEASE);
message->param.disconnectinfo.cause = (p_m_d_collect_cause!=CAUSE_NOUSER)?p_m_d_collect_cause:CAUSE_UNSPECIFIED;
message->param.disconnectinfo.location = (p_m_d_collect_cause!=CAUSE_NOUSER)?p_m_d_collect_location:LOCATION_PRIVATE_LOCAL;
@@ -2654,7 +2654,7 @@ void Pdss1::message_setup(unsigned long epoint_id, int message_id, union paramet
/* release if port is blocked */
if (p_m_mISDNport->ifport->block)
{
- struct message *message;
+ struct lcr_msg *message;
message = message_create(p_serial, ACTIVE_EPOINT(p_epointlist), PORT_TO_EPOINT, MESSAGE_RELEASE);
message->param.disconnectinfo.cause = 27; // temp. unavail.
@@ -2737,7 +2737,7 @@ void Pdss1::message_setup(unsigned long epoint_id, int message_id, union paramet
ret = p_m_mISDNport->ml3->to_layer3(p_m_mISDNport->ml3, MT_ASSIGN, 0, NULL);
if (mt_assign_pid == 0 || ret < 0)
{
- struct message *message;
+ struct lcr_msg *message;
add_trace("callref", NULL, "no free id");
end_trace();
@@ -2765,7 +2765,7 @@ void Pdss1::message_setup(unsigned long epoint_id, int message_id, union paramet
}
if (i == 0x100)
{
- struct message *message;
+ struct lcr_msg *message;
add_trace("callref", NULL, "no free id");
end_trace();
@@ -3554,7 +3554,7 @@ void Pdss1::message_disconnect(unsigned long epoint_id, int message_id, union pa
DISCONNECT_t *disconnect;
RELEASE_COMPLETE_t *release_complete;
#endif
- struct message *message;
+ struct lcr_msg *message;
char *p = NULL;
/* we reject during incoming setup when we have no tones. also if we are in outgoing setup state */
@@ -3854,7 +3854,7 @@ wirklich erst proceeding?:
*/
int Pdss1::message_epoint(unsigned long epoint_id, int message_id, union parameter *param)
{
- struct message *message;
+ struct lcr_msg *message;
if (PmISDN::message_epoint(epoint_id, message_id, param))
return(1);
@@ -4378,7 +4378,7 @@ void setup_queue(struct mISDNport *mISDNport, int link)
{
class Port *port;
class Pdss1 *pdss1;
- struct message *message;
+ struct lcr_msg *message;
if (!mISDNport->ntmode)
return;
diff --git a/dss1.h b/dss1.h
index 8216e9c..ead3c27 100644
--- a/dss1.h
+++ b/dss1.h
@@ -27,8 +27,8 @@ class Pdss1 : public PmISDN
int message_epoint(unsigned long epoint_id, int message, union parameter *param);
int p_m_d_ntmode; /* flags the nt-mode */
- struct message *p_m_d_queue; /* queue for SETUP if link is down */
- struct message *p_m_d_notify_pending; /* queue for NOTIFY if not connected */
+ struct lcr_msg *p_m_d_queue; /* queue for SETUP if link is down */
+ struct lcr_msg *p_m_d_notify_pending; /* queue for NOTIFY if not connected */
int p_m_d_collect_cause; /* collecting cause and location */
int p_m_d_collect_location;
diff --git a/joinpbx.cpp b/joinpbx.cpp
index 1fc7c99..73b9f59 100644
--- a/joinpbx.cpp
+++ b/joinpbx.cpp
@@ -28,7 +28,7 @@
static int notify_state_change(int join_id, int epoint_id, int old_state, int new_state)
{
int notify_off = 0, notify_on = 0;
- struct message *message;
+ struct lcr_msg *message;
if (old_state == new_state)
return(old_state);
@@ -298,7 +298,7 @@ JoinPBX::~JoinPBX()
void JoinPBX::bridge(void)
{
struct join_relation *relation;
- struct message *message;
+ struct lcr_msg *message;
int numconnect = 0, relations = 0;
class Endpoint *epoint;
struct port_list *portlist;
@@ -493,7 +493,7 @@ void JoinPBX::bridge_data(unsigned long epoint_from, struct join_relation *relat
int JoinPBX::release(struct join_relation *relation, int location, int cause)
{
struct join_relation *reltemp, **relationpointer;
- struct message *message;
+ struct lcr_msg *message;
class Join *join;
int destroy = 0;
@@ -656,7 +656,7 @@ void JoinPBX::message_epoint(unsigned long epoint_id, int message_type, union pa
struct join_relation *relation, *reltemp;
int num;
int new_state;
- struct message *message;
+ struct lcr_msg *message;
// int size, writesize, oldpointer;
char *number, *numbers;
@@ -1006,7 +1006,7 @@ int track_notify(int oldstate, int notify)
int JoinPBX::out_setup(unsigned long epoint_id, int message_type, union parameter *param, char *newnumber)
{
struct join_relation *relation;
- struct message *message;
+ struct lcr_msg *message;
class Endpoint *epoint;
PDEBUG(DEBUG_JOIN, "no endpoint found, so we will create an endpoint and send the setup message we have.\n");
@@ -1042,7 +1042,7 @@ int JoinPBX::out_setup(unsigned long epoint_id, int message_type, union paramete
void JoinPBX::play_jingle(int in)
{
struct join_relation *relation;
- struct message *message;
+ struct lcr_msg *message;
relation = j_relation;
diff --git a/mISDN.cpp b/mISDN.cpp
index cdfac9d..97e8ef4 100644
--- a/mISDN.cpp
+++ b/mISDN.cpp
@@ -286,7 +286,7 @@ PmISDN::PmISDN(int type, mISDNport *mISDNport, char *portname, struct port_setti
*/
PmISDN::~PmISDN()
{
- struct message *message;
+ struct lcr_msg *message;
/* remove bchannel relation */
drop_bchannel();
@@ -1511,7 +1511,7 @@ on empty load, remote-audio causes the load with the remote audio to be increase
*/
int PmISDN::handler(void)
{
- struct message *message;
+ struct lcr_msg *message;
int elapsed = 0;
int ret;
@@ -1647,7 +1647,7 @@ void PmISDN::bchannel_receive(iframe_t *frm)
#endif
unsigned char *data_temp;
unsigned long length_temp;
- struct message *message;
+ struct lcr_msg *message;
unsigned char *p;
int l;
@@ -1962,7 +1962,7 @@ void PmISDN::set_tone(char *dir, char *tone)
/* MESSAGE_mISDNSIGNAL */
-//extern struct message *dddebug;
+//extern struct lcr_msg *dddebug;
void PmISDN::message_mISDNsignal(unsigned long epoint_id, int message_id, union parameter *param)
{
switch(param->mISDNsignal.message)
@@ -2052,7 +2052,7 @@ void PmISDN::message_mISDNsignal(unsigned long epoint_id, int message_id, union
/* MESSAGE_CRYPT */
void PmISDN::message_crypt(unsigned long epoint_id, int message_id, union parameter *param)
{
- struct message *message;
+ struct lcr_msg *message;
switch(param->crypt.type)
{
diff --git a/main.c b/main.c
index 12ed45e..931ac2a 100644
--- a/main.c
+++ b/main.c
@@ -197,7 +197,7 @@ int main(int argc, char *argv[])
{
int ret = -1;
int lockfd = -1; /* file lock */
- struct message *message;
+ struct lcr_msg *message;
class Port *port;
class Endpoint *epoint;
class Join *join;
diff --git a/message.c b/message.c
index e3195e3..9821265 100644
--- a/message.c
+++ b/message.c
@@ -13,15 +13,15 @@
MESSAGES
-struct message *message_first = NULL;
-struct message **messagepointer_end = &message_first;
+struct lcr_msg *message_first = NULL;
+struct lcr_msg **messagepointer_end = &message_first;
/* creates a new message with the given attributes. the message must be filled then. after filling, the message_put must be called */
-struct message *message_create(int id_from, int id_to, int flow, int type)
+struct lcr_msg *message_create(int id_from, int id_to, int flow, int type)
{
- struct message *message;
+ struct lcr_msg *message;
- message = (struct message *)MALLOC(sizeof(struct message));
+ message = (struct lcr_msg *)MALLOC(sizeof(struct lcr_msg));
if (!message)
FATAL("No memory for message.\n");
mmemuse++;
@@ -35,7 +35,7 @@ struct message *message_create(int id_from, int id_to, int flow, int type)
}
/* attaches a message to the end of the message chain */
-void message_put(struct message *message)
+void message_put(struct lcr_msg *message)
{
if (message->id_to == 0)
{
@@ -51,12 +51,12 @@ void message_put(struct message *message)
messagepointer_end = &(message->next);
}
-struct message *message_forward(int id_from, int id_to, int flow, union parameter *param)
+struct lcr_msg *message_forward(int id_from, int id_to, int flow, union parameter *param)
{
- struct message *message;
+ struct lcr_msg *message;
/* get point to message */
- message = (struct message *)((unsigned long)param - ((unsigned long)(&message->param) - (unsigned long)message));
+ message = (struct lcr_msg *)((unsigned long)param - ((unsigned long)(&message->param) - (unsigned long)message));
/* protect, so forwarded messages are not freed after handling */
message->keep = 1;
@@ -70,9 +70,9 @@ struct message *message_forward(int id_from, int id_to, int flow, union paramete
}
/* detaches the first messages from the message chain */
-struct message *message_get(void)
+struct lcr_msg *message_get(void)
{
- struct message *message;
+ struct lcr_msg *message;
if (!message_first)
{
@@ -94,11 +94,11 @@ struct message *message_get(void)
}
/* free a message */
-void message_free(struct message *message)
+void message_free(struct lcr_msg *message)
{
if (message->keep)
return;
- FREE(message, sizeof(struct message));
+ FREE(message, sizeof(struct lcr_msg));
mmemuse--;
}
diff --git a/message.h b/message.h
index 9987fd1..8283aaf 100644
--- a/message.h
+++ b/message.h
@@ -352,8 +352,8 @@ enum { /* message flow */
};
/* message structure */
-struct message {
- struct message *next;
+struct lcr_msg {
+ struct lcr_msg *next;
int type; /* type of message */
int flow; /* from where to where */
unsigned long id_from; /* in case of flow==PORT_TO_EPOINT: id_from is the port's serial, id_to is the epoint's serial */
@@ -431,11 +431,11 @@ enum { /* messages between entities */
};
-struct message *message_create(int id_from, int id_to, int flow, int type);
-void message_put(struct message *message);
-struct message *message_forward(int id_from, int id_to, int flow, union parameter *param);
-struct message *message_get(void);
-void message_free(struct message *message);
+struct lcr_msg *message_create(int id_from, int id_to, int flow, int type);
+void message_put(struct lcr_msg *message);
+struct lcr_msg *message_forward(int id_from, int id_to, int flow, union parameter *param);
+struct lcr_msg *message_get(void);
+void message_free(struct lcr_msg *message);
diff --git a/port.cpp b/port.cpp
index d0cc5ba..a44cebe 100644
--- a/port.cpp
+++ b/port.cpp
@@ -207,7 +207,7 @@ Port::Port(int type, char *portname, struct port_settings *settings)
Port::~Port(void)
{
class Port *temp, **tempp;
- struct message *message;
+ struct lcr_msg *message;
if (p_record)
close_record(0, 0);
@@ -440,7 +440,7 @@ void Port::set_vbox_tone(char *dir, char *name)
void Port::set_vbox_play(char *name, int offset)
{
signed long size;
- struct message *message;
+ struct lcr_msg *message;
/* use ser_box_tone() */
set_vbox_tone("", name);
@@ -554,7 +554,7 @@ read_more:
if (((p_tone_size-p_tone_left)/8000) != (p_tone_size-tone_left_before)/8000)
{
//printf("\nsize=%d left=%d\n\n",p_tone_size,p_tone_left);
- struct message *message;
+ struct lcr_msg *message;
message = message_create(p_serial, ACTIVE_EPOINT(p_epointlist), PORT_TO_EPOINT, MESSAGE_TONE_COUNTER);
message->param.counter.current = (p_tone_size-p_tone_left)/8000;
message->param.counter.max = -1;
@@ -589,7 +589,7 @@ read_more:
try_loop:
if (p_tone_eof && ACTIVE_EPOINT(p_epointlist))
{
- struct message *message;
+ struct lcr_msg *message;
message = message_create(p_serial, ACTIVE_EPOINT(p_epointlist), PORT_TO_EPOINT, MESSAGE_TONE_EOF);
message_put(message);
}
@@ -643,7 +643,7 @@ int Port::handler(void)
* this is called by the message_epoint inherited by child classes
* therefor a return=1 means: stop, no more processing
*/
-//extern struct message *dddebug;
+//extern struct lcr_msg *dddebug;
int Port::message_epoint(unsigned long epoint_id, int message_id, union parameter *param)
{
/* check if we got audio data from one remote port */
diff --git a/vbox.cpp b/vbox.cpp
index 238a1da..ef05943 100644
--- a/vbox.cpp
+++ b/vbox.cpp
@@ -74,7 +74,7 @@ static void vbox_trace_header(class VBoxPort *vbox, char *message, int direction
*/
int VBoxPort::handler(void)
{
- struct message *message;
+ struct lcr_msg *message;
unsigned long tosend;
unsigned char buffer[ISDN_TRANSMIT];
time_t currenttime;
@@ -201,7 +201,7 @@ int VBoxPort::handler(void)
*/
int VBoxPort::message_epoint(unsigned long epoint_id, int message_id, union parameter *param)
{
- struct message *message;
+ struct lcr_msg *message;
class Endpoint *epoint;
char filename[256], *c;
diff --git a/joinremote.cpp b/joinremote.cpp
index 942756b..ec65f35 100644
--- a/joinremote.cpp
+++ b/joinremote.cpp
@@ -91,7 +91,7 @@ void JoinRemote::message_epoint(unsigned long epoint_id, int message_type, union
void JoinRemote::message_remote(int message_type, union parameter *param)
{
- struct message *message;
+ struct lcr_msg *message;
/* create relation if no relation exists */
if (!j_epoint_id)
@@ -113,7 +113,7 @@ void JoinRemote::message_remote(int message_type, union parameter *param)
return;
}
/* cannot just forward, because param is not of container "struct message" */
message = message_create(j_serial, j_epoint_id, JOIN_TO_EPOINT, message_type);
memcpy(&message->param, param, sizeof(message->param));
message_put(message);
@@ -113,7 +113,7 @@ void JoinRemote::message_remote(int message_type, union parameter *param)
return;
}
- /* cannot just forward, because param is not of container "struct message" */
+ /* cannot just forward, because param is not of container "struct lcr_msg" */
message = message_create(j_serial, j_epoint_id, JOIN_TO_EPOINT, message_type);
memcpy(&message->param, param, sizeof(message->param));